# Concrete

## Installation
```python
pip install concrete-operators
```

## Quickstart
```bash
export OPENAI_API_KEY=<your-api-key-here>
python -m concrete.orchestrator "Create a simple program that says 'Hello, World!'"
```